==> limny-3.0.0.tar.bz2: limny-3.0.0/admin/preview.php <==
<?php

/*
 * preview.php
 *
 * @copyright     Copyright 2009-2011 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

require('../init.php');

session_name('_limny');
session_start();

require('admin.class.php');
require('../incs/user.class.php');
require('../incs/config.class.php');

$class['admin'] = new Admin;
echo $class['admin']->check_session();

if(!$class['admin']->is_permitted('appearance'))
{
	header('Location: index.php');
}

if(!isset($_GET['theme']))
{
	header('Location: index.php');
}

if(!in_array($_GET['theme'], $class['admin']->installed_themes()))
{
	header('Location: index.php');
}

include(__PATH__ . '/incs/role.class.php');
include(__PATH__ . '/incs/language.class.php');
include(__PATH__ . '/incs/theme.class.php');
include(__PATH__ . '/incs/page.class.php');
include(__PATH__ . '/incs/application.class.php');
include(__PATH__ . '/incs/content.class.php');
include(__PATH__ . '/incs/widget.class.php');
include(__PATH__ . '/incs/permalink.class.php');

$class['config'] = new Config;
$theme = $class['config']->theme;
$db->update('config', 'value=\'' . add_slashes($_GET['theme']) . '\' WHERE name=\'theme\'');

$class['language'] = new Language;
include_once(__PATH__ . '/langs/'.$class['language']->language.'/main.php');

$class['page'] = new Page;
$class['page']->make();
print $class['page']->_page;

$db->update('config', 'value=\'' . add_slashes($theme) . '\' WHERE name=\'theme\'');

?>

==> limny-3.2.1.tar.bz2: limny-3.2.1/admin/preview.php <==
<?php

/*
 * preview.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

require('../init.php');

session_name('_limny');
session_start();

require('admin.class.php');
require('../incs/user.class.php');
require('../incs/config.class.php');

$class['admin'] = new Admin;
$class['admin']->check_session();

if (!$class['admin']->is_permitted('appearance'))
{
	header('Location: index.php');
	exit;
}

if(!isset($_GET['theme']))
{
	header('Location: index.php');
	exit;
}

if(!in_array($_GET['theme'], $class['admin']->installed_themes()))
{
	header('Location: index.php');
	exit;
}

include(__PATH__ . '/incs/role.class.php');
include(__PATH__ . '/incs/language.class.php');
include(__PATH__ . '/incs/theme.class.php');
include(__PATH__ . '/incs/page.class.php');
include(__PATH__ . '/incs/application.class.php');
include(__PATH__ . '/incs/content.class.php');
include(__PATH__ . '/incs/widget.class.php');
include(__PATH__ . '/incs/permalink.class.php');

$class['config'] = new Config;
$theme = $class['config']->theme;
$db->update('config', array('value' => '\'' . $db->escape($_GET['theme']) . '\''), array('name' => '=\'theme\''));

$class['language'] = new Language;
include_once(__PATH__ . '/langs/'.$class['language']->language.'/main.php');

$class['page'] = new Page;
$class['page']->make();
print $class['page']->_page;

$db->update('config', array('value' => '\'' . $db->escape($theme) . '\''), array('name' => '=\'theme\''));

?>
